@@ -1,4 +1,4 @@
-ggContPlot <- function(v, partial, band, rug, whitespace, strip.names, overlay, line.par, fill.par, points.par, ...) {
+ggContPlot <- function(v, partial, band, rug, whitespace, strip.names, overlay, top, line.par, fill.par, points.par, ...) {
 
   # Setup data frames
   xx <- v$fit[, v$meta$x]
@@ -54,24 +54,49 @@ ggContPlot <- function(v, partial, band, rug, whitespace, strip.names, overlay,
     p <- p + do.call("geom_polygon", fill.args, envir=asNamespace("ggplot2"))
   }
   line.args$data <- lineData
-  p <- p + do.call("geom_line", line.args, envir=asNamespace("ggplot2"))
-  if (partial) {
+  if (!partial) {
+    p <- p + do.call("geom_line", line.args, envir=asNamespace("ggplot2"))
+  } else {
     point.args$data <- pointData
-    p <- p + do.call("geom_point", point.args, envir=asNamespace("ggplot2"))
+    if (top == 'line') {
+      p <- p + do.call("geom_point", point.args, envir=asNamespace("ggplot2"))
+      p <- p + do.call("geom_line", line.args, envir=asNamespace("ggplot2"))
+    } else {
+      p <- p + do.call("geom_line", line.args, envir=asNamespace("ggplot2"))
+      p <- p + do.call("geom_point", point.args, envir=asNamespace("ggplot2"))
+    }
+  }
+  if (rug==1) {
+    rug.args <- point.args
+    rug.args$sides <- 'b'
+    p <- p + do.call("geom_rug", point.args, envir=asNamespace("ggplot2"))
   }
-  if (rug==1) p <- p + ggplot2::geom_rug(data=pointData, mapping=ggplot2::aes_string(color=v$meta$by), sides='b')
   if (rug==2) {
-    p <- p + ggplot2::geom_rug(data=pointData[v$res$visregPos,], mapping=ggplot2::aes_string(color=v$meta$by), sides='t')
-    p <- p + ggplot2::geom_rug(data=pointData[!v$res$visregPos,], mapping=ggplot2::aes_string(color=v$meta$by), sides='b')
+    top.args <- bot.args <- point.args
+    top.args$sides <- 't'
+    bot.args$sides <- 'b'
+    top.args$data <- pointData[v$res$visregPos,]
+    bot.args$data <- pointData[!v$res$visregPos,]
+    p <- p + do.call("geom_rug", top.args, envir=asNamespace("ggplot2"))
+    p <- p + do.call("geom_rug", bot.args, envir=asNamespace("ggplot2"))
   }
-
+  
   # Facet
   if ("by" %in% names(v$meta) & !overlay) {
     form <- as.formula(paste("~", v$meta$by))
-    if (strip.names==TRUE) {
+    K <- length(levels(bb))
+    if (identical(strip.names, TRUE)) {
       p <- p + ggplot2::facet_grid(form, labeller=ggplot2::label_both)
-    } else {
+    } else if (identical(strip.names, FALSE)) {
       p <- p + ggplot2::facet_grid(form)
+    } else if (is.character(strip.names) & length(strip.names) == K) {
+      names(strip.names) <- levels(bb)
+      args <- list(strip.names)
+      names(args) <- v$meta$by
+      lbl <- do.call(ggplot2::labeller, args)
+      p <- p + ggplot2::facet_grid(form, labeller=lbl)
+    } else {
+      stop('strip.names must either be logical or a character vector with length equal to the number of facets', call.=FALSE)
     }
   }
   return(p)
