@@ -1,4 +1,4 @@
-visregPanel <- function(x, y, subscripts, lframe, lresids, partial, band, rug, fill.par, ...) {
+visregPanel <- function(x, y, subscripts, lframe, lresids, partial, band, rug, top, fill.par, ...) {
   if (band) {
     poly.args <- list(x=c(lframe$xx[subscripts], rev(lframe$xx[subscripts])), y=c(lframe$lwr[subscripts], rev(lframe$upr[subscripts])), subscripts=subscripts, col="gray85", border=F)
     if (length(fill.par)) poly.args[names(fill.par)] <- fill.par
@@ -6,8 +6,18 @@ visregPanel <- function(x, y, subscripts, lframe, lresids, partial, band, rug, f
     do.call(FUN, poly.args)
   }
   current.level <- lframe$by[subscripts][1]
-  lattice::panel.xyplot(x, y, subscripts=subscripts,...)
-  if (partial) lattice::panel.points(lresids$x[lresids$by==current.level], lresids$r[lresids$by==current.level])
+  if (!partial) {
+    lattice::panel.xyplot(x, y, subscripts=subscripts,...)
+  } else {
+    if (top=='line') {
+      lattice::panel.points(lresids$x[lresids$by==current.level], lresids$r[lresids$by==current.level])
+      lattice::panel.xyplot(x, y, subscripts=subscripts,...)
+    } else {
+      lattice::panel.xyplot(x, y, subscripts=subscripts,...)
+      lattice::panel.points(lresids$x[lresids$by==current.level], lresids$r[lresids$by==current.level])
+    }
+  }
+  
   if (rug==1) lattice::panel.rug(lresids$x[lresids$by==current.level], lwd=1)
   if (rug==2) {
     lattice::panel.rug(lresids$x[lresids$by==current.level & !lresids$pos], lwd=1)
