@@ -1,15 +1,15 @@
 # Setup
-require(survival)
+library(survival)
 data(ovarian)
 ovarian$rx <- factor(ovarian$rx)
 
 # Basic
-fit <- coxph(Surv(futime,fustat)~age+rx,data=ovarian)
-visreg(fit,"age")
-visreg(fit,"age", type="contrast")
-visreg(fit,"rx")
+fit <- coxph(Surv(futime,fustat) ~ age + rx, data=ovarian)
+visreg(fit, "age")
+visreg(fit, "age", type="contrast")
+visreg(fit, "rx")
 visreg(fit, "age", trans=exp)
-visreg(fit,"age",trans=exp,ylim=c(0,20))
+visreg(fit, "age", trans=exp, ylim=c(0,20))
 
 # Interaction
 fit <- coxph(Surv(futime,fustat)~age*rx,data=ovarian)
@@ -33,3 +33,8 @@ ovarian$Group <- factor(ovarian$rx)
 fit <- coxph(Surv(futime,fustat) ~ age+strata(Group), data=ovarian)
 visreg(fit, "age")
 visreg(fit, "age", type='contrast')
+
+# Logical
+ovarian$rx <- ovarian$rx == 2
+fit <- coxph(Surv(futime,fustat) ~ age + rx, data=ovarian)
+visreg(fit, "age")
